# TheBeans


[![image](https://img.shields.io/pypi/v/TheBeans.svg)](https://pypi.python.org/pypi/TheBeans)
[![image](https://img.shields.io/conda/vn/conda-forge/TheBeans.svg)](https://anaconda.org/conda-forge/TheBeans)


**Python package with the beans.**


-   Free software: MIT License
-   Documentation: https://phillipslucas.github.io/TheBeans
    

## Features

-   TODO
